@@ -155,6 +155,8 @@ static XtResource resources[] = {
 
   { "bboxcolor", "BBoxColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, bboxpix), XtRString, "greenyellow"},
+  { "clipcolor", "ClipColor", XtRPixel, sizeof(Pixel),
+      XtOffset(ApplicationDataPtr, clipcolor), XtRString, "powderblue"},
 
   /* GUI Color scheme 1 */
 
@@ -1018,7 +1020,10 @@ void outputpopup(xcWidget button, caddr_t clientdata, caddr_t calldata)
    sprintf(statics[5], "Orientation:");
    sprintf(statics[6], "Mode:");
 
-   sprintf(edit[0], "%s", curpage->filename);
+   if (curpage->filename)
+      sprintf(edit[0], "%s", curpage->filename);
+   else
+      sprintf(edit[0], "Page %d", areawin->page + 1);
    sprintf(edit[1], "%s", topobject->name);
 
    /* recompute bounding box and auto-scale, if set */
